@@ -1,3 +1,5 @@
+import shutil
+
 from .loader import load_entry_points
 
 main = load_entry_points()
@@ -5,4 +7,4 @@ main = load_entry_points()
 
 if __name__ == "__main__":
     # Execute right away if the module is directly called from CLI.
-    main()
+    main(max_content_width=shutil.get_terminal_size().columns - 2)
